<?php
/*
Plugin Name: RegisterONE Vendor and Event Resource Management
Plugin URI: https://www.registerone.com
Description: Embed RegisterONE event registration forms into your Wordpress website.
Version: 1.0.17
Author: RegisterONE
Author URI: http://www.registerone.com
License: GPL v2
*/

/* exit if accessed directly*/
if (!defined('ABSPATH')) exit;

if(!class_exists('RegisteroneWordpressClient')) {

    define( 'REGISTERONE_WORDPRESS_CLIENT_PATH',     dirname( __FILE__ ) );
    define( 'REGISTERONE_WORDPRESS_CLIENT_URL',      plugins_url( '', __FILE__ ) );
    define( 'REGISTERONE_WORDPRESS_CLIENT_FILE',     plugin_basename( __FILE__ ) );
    define( 'REGISTERONE_WORDPRESS_CLIENT_ASSETS', REGISTERONE_WORDPRESS_CLIENT_URL . '/assets' );
    define( 'REGISTERONE_WORDPRESS_CLIENT_FRONTEND', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end');

    class RegisteroneWordpressClient {

        public $error_text = '';
        public $short_code = 'registerone_form';
        public $registerone_form_shortcode;

        /**
         * A Unique Identifier
         */
        protected $plugin_slug;

        /**
         * A reference to an instance of this class.
         */
        private static $instance;

        /**
         * The array of templates that this plugin tracks.
         */
        protected $templates;

        public function __construct()
        {
            global $post;

            $this->templates = array();

            spl_autoload_register( array( $this, 'autoload' ) );
            $registeroneSettings = new RegisteroneMain();

            add_action('admin_enqueue_scripts', array($this, 'dwc_admin_styles'));
            add_action('wp_enqueue_scripts', array($this, 'dwc_frontend_scripts'));

            // removes theme styles and scripts before displaying form
            // also disables emoji in header
            add_action( 'wp_enqueue_scripts', array($this, 'dwc_remove_scripts_and_styles'),100);

            // Add a filter to the attributes metabox to inject blank template into the cache.
            add_filter(
                'page_attributes_dropdown_pages_args',
                array( $this, 'register_project_templates' )
            );

            // Add a filter to the save post to inject blank template into the page cache
            add_filter(
                'wp_insert_post_data',
                array( $this, 'register_project_templates' )
            );

            // Add a filter to the template include to determine if the page has our
            // blank template assigned and return it's path
            add_filter(
                'template_include',
                array( $this, 'view_project_template' )
            );

            // Add blank template files to this array.
            $this->templates = array(
                'registerone-template.php' => 'RegisterONE Template',
            );

            $this->registerone_form_shortcode = new RegisteroneShortcodes();
            register_activation_hook(__FILE__, array($this, 'dwc_plugin_activation'));
            register_deactivation_hook(__FILE__, array($this, 'dwc_plugin_deactivation'));
        }

        /**
         * @param $key
         * @return bool
         */
        private function _check_screen_key($key)
        {
            return array_key_exists($key, $_GET);
        }

        /**
         *
         */
        public function dwc_admin_styles(){
            wp_register_script('dwc admin js', REGISTERONE_WORDPRESS_CLIENT_URL . '/admin/assets/js/regone-admin.js', array('jquery'), '201610201101');
            wp_enqueue_script('dwc admin js');

            wp_localize_script('dwc admin js', 'dwc_ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' )) );

            wp_register_style('dwc admin', REGISTERONE_WORDPRESS_CLIENT_URL . '/admin/assets/css/regone-admin-styles.css' );
            wp_enqueue_style('dwc admin');
        }

		public function dwc_remove_scripts_and_styles() {
			global $wp_scripts;
			global $wp_styles;
            global $post;

            if( is_a( $post, 'WP_Post' ) && has_shortcode( $post->post_content, $this->short_code)){

                // Runs through the queue scripts
                foreach ($wp_scripts->queue as $handle) :
                    if (!is_numeric(strpos($handle, 'dwc'))) {
                        wp_dequeue_script($handle);
                        wp_deregister_script($handle);
                    }
                endforeach;

                // Runs through the queue styles
                foreach ($wp_styles->queue as $handle) :
                    if (!is_numeric(strpos($handle, 'dwc'))) {
                        wp_dequeue_style($handle);
                        wp_deregister_style($handle);
                    }
                endforeach;

                // disable emojis
                remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
                remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
                remove_action( 'wp_print_styles', 'print_emoji_styles' );
                remove_action( 'admin_print_styles', 'print_emoji_styles' );

                // add_action( 'wp_enqueue_scripts', array($this, 'dwc_frontend_scripts'));
            }
		}

        /**
         *
         */
        public function dwc_frontend_scripts() {
            global $post;

            if( is_a( $post, 'WP_Post' ) && has_shortcode( $post->post_content, $this->short_code)){

                if ($this->_check_screen_key("map")) {

                    wp_register_style('dwc frontend font-awesome-min css', '//opensource.keycdn.com/fontawesome/4.7.0/font-awesome.min.css');
                    wp_enqueue_style('dwc frontend font-awesome-min css');

                    wp_register_style('dwc frontend ace-fonts css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/ace/ace-fonts.css');
                    wp_enqueue_style('dwc frontend ace-fonts css');

                    wp_register_style('dwc frontend map_custom css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/map_custom.css');
                    wp_enqueue_style('dwc frontend map_custom css');

                    wp_register_style('dwc frontend imagemap-summer css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemap/summer.css');
                    wp_enqueue_style('dwc frontend imagemap-summer css');

                    wp_register_style('dwc frontend imagemap-summer-custom css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemap/summer_custom.css');
                    wp_enqueue_style('dwc frontend imagemap-summer-custom css');

                    wp_register_style('dwc frontend sweetalert css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/sweetalert/sweetalert.min.css');
                    wp_enqueue_style('dwc frontend sweetalert css');

                    wp_register_script('dwc jquery js', '/wp-includes/js/jquery/jquery.js', array(), '201703210738');
                    wp_enqueue_script('dwc jquery js');

                    wp_register_script('dwc require js', '/wp-includes/js/require.js', array(), '201703210738');
                    wp_enqueue_script('dwc require js');

                    wp_register_script('dwc form-image-map-creator js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemap/form-image-map-creator.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-image-map-creator js');

                    wp_register_script('dwc imagemapster-redist-when js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemapster/redist/when.js', array(), '201703210738');
                    wp_enqueue_script('dwc imagemapster-redist-when js');

                    wp_register_script('dwc imagemapster-core js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemapster/core.js', array(), '201703210738');
                    wp_enqueue_script('dwc imagemapster-core js');

                    wp_register_script('dwc imagemapster-graphics js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemapster/graphics.js', array(), '201703210738');
                    wp_enqueue_script('dwc imagemapster-graphics js');

                    wp_register_script('dwc imagemapster-mapimage js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemapster/mapimage.js', array(), '201703210738');
                    wp_enqueue_script('dwc imagemapster-mapimage js');

                    wp_register_script('dwc imagemapster-mapdata js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemapster/mapdata.js', array(), '201703210738');
                    wp_enqueue_script('dwc imagemapster-mapdata js');

                    wp_register_script('dwc imagemapster-areadata js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemapster/areadata.js', array(), '201703210738');
                    wp_enqueue_script('dwc imagemapster-areadata js');

                    wp_register_script('dwc imagemapster-areacorners js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemapster/areacorners.js', array(), '201703210738');
                    wp_enqueue_script('dwc imagemapster-areacorners js');

                    wp_register_script('dwc imagemapster-scale js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemapster/scale.js', array(), '201703210738');
                    wp_enqueue_script('dwc imagemapster-scale js');

                    wp_register_script('dwc imagemapster-tooltip js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/imagemapster/tooltip.js', array(), '201703210738');
                    wp_enqueue_script('dwc imagemapster-tooltip js');

                    wp_register_script('dwc sweetalert js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/sweetalert/sweetalert.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc sweetalert js');

                    wp_register_script('dwc form-map js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-map.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-map js');

                } elseif ($this->_check_screen_key("signature")) {

                    wp_register_style('dwc frontend form-signature-pad css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/signature-pad/css/form-signature-pad.css');
                    wp_enqueue_style('dwc frontend form-signature-pad css');

                    wp_register_style('dwc frontend form-signature-pad-custom css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/signature-pad/css/form-signature-pad-custom.css');
                    wp_enqueue_style('dwc frontend form-signature-pad-custom css');

                    wp_register_script('dwc jquery js', '/wp-includes/js/jquery/jquery.js', array(), '201703210738');
                    wp_enqueue_script('dwc jquery js');

                    wp_register_script('dwc form-signature-pad js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/signature-pad/js/form-signature-pad.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-signature-pad js');

                } elseif ($this->_check_screen_key("terms")) {

                    wp_register_style('dwc frontend font-awesome-min css', '//opensource.keycdn.com/fontawesome/4.7.0/font-awesome.min.css');
                    wp_enqueue_style('dwc frontend font-awesome-min css');

                    wp_register_style('dwc frontend form-reset css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-reset.css');
                    wp_enqueue_style('dwc frontend form-reset css');

                    wp_register_style('dwc frontend form-color-blue css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-color-blue.css');
                    wp_enqueue_style('dwc frontend form-color-blue css');

                    wp_register_style('dwc frontend form-base css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-base.css');
                    wp_enqueue_style('dwc frontend form-base css');

                    wp_register_style('dwc frontend form-build css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-build.css');
                    wp_enqueue_style('dwc frontend form-build css');

                    wp_register_script('dwc jquery js', '/wp-includes/js/jquery/jquery.js', array(), '201703210738');
                    wp_enqueue_script('dwc jquery js');

                    wp_register_style('dwc summernote css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/summernote/summernote-lite.css');
                    wp_enqueue_style('dwc summernote css');

                    wp_register_script('dwc summernote js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/summernote/summernote-lite.js', array(), '201703210738');
                    wp_enqueue_script('dwc summernote js');

                    wp_register_script('dwc form-response js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-response.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-response js');

                    wp_register_style('dwc frontend form-terms css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-terms.css');
                    wp_enqueue_style('dwc frontend form-terms css');

                    wp_register_style('dwc frontend form-custom css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-custom.css');
                    wp_enqueue_style('dwc frontend form-custom css');

                } elseif ($this->_check_screen_key("amenities")) {

                    wp_register_style('dwc frontend jquery-confirm css', '//cdnjs.cloudflare.com/ajax/libs/jquery-confirm/3.3.0/jquery-confirm.min.css');
                    wp_enqueue_style('dwc frontend jquery-confirm css');

                    wp_register_style('dwc frontend form-fileinput css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-fileinput.css');
                    wp_enqueue_style('dwc frontend form-fileinput css');

                    wp_register_style('dwc frontend font-awesome-min css', '//opensource.keycdn.com/fontawesome/4.7.0/font-awesome.min.css');
                    wp_enqueue_style('dwc frontend font-awesome-min css');

                    wp_register_style('dwc frontend form-reset css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-reset.css');
                    wp_enqueue_style('dwc frontend form-reset css');

                    wp_register_style('dwc frontend form-color-blue css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-color-blue.css');
                    wp_enqueue_style('dwc frontend form-color-blue css');

                    wp_register_style('dwc frontend form-base css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-base.css');
                    wp_enqueue_style('dwc frontend form-base css');

                    wp_register_style('dwc frontend form-build css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-build.css');
                    wp_enqueue_style('dwc frontend form-build css');

                    wp_register_style('dwc frontend form-custom css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-custom.css');
                    wp_enqueue_style('dwc frontend form-custom css');

                    wp_register_script('dwc jquery js', '/wp-includes/js/jquery/jquery.js', array(), '201703210738');
                    wp_enqueue_script('dwc jquery js');

                    wp_register_script('dwc form-trumbowyg js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-trumbowyg.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-trumbowyg js');

                    wp_register_script('dwc form-select2 js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/select2.full.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-select2 js');

                    wp_register_style('dwc parsle css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/parsley.css');
                    wp_enqueue_style('dwc parsle css');

                    wp_register_script('dwc parsley js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/parsley.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc parsley js');

                    wp_register_script('dwc form-purify js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-purify.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-purify js');

                    wp_register_script('dwc form-fileinput js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-fileinput.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-fileinput js');

                    wp_register_script('dwc form-inputmask-bundle js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/jquery.inputmask.bundle.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-inputmask-bundle js');

                    wp_register_script('dwc form-response js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-response.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-response js');

                    wp_register_script('dwc jbox js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/jbox/jBox.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc jbox js');

                    wp_register_style('dwc frontend jbox css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/jbox/jBox.css');
                    wp_enqueue_style('dwc frontend jbox css');

                    wp_register_script('dwc query-confirm js', '//cdnjs.cloudflare.com/ajax/libs/jquery-confirm/3.3.0/jquery-confirm.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc query-confirm js');

                    wp_register_script('dwc form-main js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-main.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-main js');
                    wp_localize_script('dwc form-main js', 'dwc_ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));

                    wp_register_script('dwc form-custom js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-custom.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-custom js');

                } else {

                    wp_register_style('dwc frontend jquery-confirm css', '//cdnjs.cloudflare.com/ajax/libs/jquery-confirm/3.3.0/jquery-confirm.min.css');
                    wp_enqueue_style('dwc frontend jquery-confirm css');

                    wp_register_style('dwc frontend form-fileinput css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-fileinput.css');
                    wp_enqueue_style('dwc frontend form-fileinput css');

                    wp_register_style('dwc frontend form-trumbowyg css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-trumbowyg.css');
                    wp_enqueue_style('dwc frontend form-trumbowyg css');

                    wp_register_style('dwc frontend form-select2 css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/select2.min.css');
                    wp_enqueue_style('dwc frontend form-select2 css');

                    wp_register_style('dwc frontend form-select2-addl css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/select2-addl.css');
                    wp_enqueue_style('dwc frontend form-select2-addl css');

                    wp_register_style('dwc frontend kv-widgets css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/kv-widgets.css');
                    wp_enqueue_style('dwc frontend kv-widgets css');

                    wp_register_style('dwc frontend font-awesome-min css', '//opensource.keycdn.com/fontawesome/4.7.0/font-awesome.min.css');
                    wp_enqueue_style('dwc frontend font-awesome-min css');

                    wp_register_style('dwc frontend form-reset css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-reset.css');
                    wp_enqueue_style('dwc frontend form-reset css');

                    wp_register_style('dwc frontend form-color-blue css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-color-blue.css');
                    wp_enqueue_style('dwc frontend form-color-blue css');

                    wp_register_style('dwc frontend form-base css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-base.css');
                    wp_enqueue_style('dwc frontend form-base css');

                    wp_register_style('dwc frontend form-build css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-build.css');
                    wp_enqueue_style('dwc frontend form-build css');

                    wp_register_style('dwc frontend form-custom css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/form-custom.css');
                    wp_enqueue_style('dwc frontend form-custom css');

                    wp_register_script('dwc jquery js', '/wp-includes/js/jquery/jquery.js', array(), '201703210738');
                    wp_enqueue_script('dwc jquery js');

                    wp_register_script('dwc form-trumbowyg js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-trumbowyg.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-trumbowyg js');

                    wp_register_script('dwc form-select2 js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/select2.full.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-select2 js');

                    wp_register_script('dwc form-sortable js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-sortable.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-sortable js');

                    wp_register_script('dwc form-purify js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-purify.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-purify js');

                    wp_register_script('dwc form-fileinput js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-fileinput.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-fileinput js');

                    wp_register_script('dwc kv-widgets js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/kv-widgets.js', array(), '201703210738');
                    wp_enqueue_script('dwc kv-widgets js');

                    wp_register_script('dwc form-inputmask-bundle js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/jquery.inputmask.bundle.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-inputmask-bundle js');

                    wp_register_script('dwc form-response js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-response.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-response js');

                    wp_register_script('dwc jbox js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/jbox/jBox.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc jbox js');

                    wp_register_style('dwc frontend jbox css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/jbox/jBox.css');
                    wp_enqueue_style('dwc frontend jbox css');

                    wp_register_style('dwc parsle css', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/css/parsley.css');
                    wp_enqueue_style('dwc parsle css');

                    wp_register_script('dwc parsley js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/parsley.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc parsley js');

                    wp_register_script('dwc query-confirm js', '//cdnjs.cloudflare.com/ajax/libs/jquery-confirm/3.3.0/jquery-confirm.min.js', array(), '201703210738');
                    wp_enqueue_script('dwc query-confirm js');

                    wp_register_script('dwc form-main js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-main.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-main js');
                    wp_localize_script('dwc form-main js', 'dwc_ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));

                    wp_register_script('dwc form-custom js', REGISTERONE_WORDPRESS_CLIENT_URL . '/front-end/assets/js/form-custom.js', array(), '201703210738');
                    wp_enqueue_script('dwc form-custom js');

                }
            }
        }

        /**
         * @param $class
         */
        public function autoload($class)
        {
            $name = explode( '_', $class );

            if(isset( $name[1] ) || isset( $name[2] )){
                if(sizeof( $name ) > 2 ) {
                    $class_name = strtolower( $name[1] ) . '-' . strtolower( $name[2] );
                    $file_name = dirname( __FILE__ ) . '/admin/classes/' . $class_name . '.php';
                } else {
                    $class_name = strtolower( $name[1] );
                    $file_name = dirname( __FILE__ ) . '/admin/classes/' . $class_name . '.php';
                }

                if(file_exists( $file_name )){
                    require_once $file_name;
                }
            }else{

                $class_name = $name[0];
                $file_name = dirname(__FILE__) . '/admin/classes/' . $class_name . '.php';

                if(file_exists($file_name)) {

                    require_once $file_name;
                }
            }
        }

        public function dwc_version_require( $error_text ) {
            if( current_user_can( 'manage_options' )) {
                echo '<div class="error"><p>' . $error_text . '</p></div>';
            }
        }

        /**
         * Merge the blank template into existing WP template array.
         */
        public function register_project_templates( $atts ) {

            // Get theme object
            $theme = wp_get_theme();

            // Create the key used for the themes cache
            $cache_key = 'page_templates-' . md5( $theme->get_theme_root() . '/' . $theme->get_stylesheet() );

            // Retrieve existing page templates
            $templates = $theme->get_page_templates();

            // Add our template(s) to the list of existing templates by merging the arrays
            $templates = array_merge( $templates, $this->templates );

            // Replace existing value in cache
            wp_cache_set( $cache_key, $templates, 'themes', 300 );

            add_filter( 'theme_page_templates', function( $page_templates ) use ( $templates ) {
                return $templates;
            });

            return $atts;
        }

        /**
         * Checks if the template is assigned to the page
         */
        public function view_project_template($template) {

            global $post;

            if(!isset( $this->templates[get_post_meta($post->ID, '_wp_page_template', true)])){
                return $template;
            }

            $file = plugin_dir_path( __FILE__ ) . get_post_meta($post->ID, '_wp_page_template', true);

            // Just to be safe, we check if the file exist first
            if(file_exists( $file )){
                return $file;
            }else{
                echo $file;
            }
            return $template;
        }

        /**
         *
         */
        public function dwc_plugin_activation()
        {
            if( version_compare( PHP_VERSION, '5.2.6', '<')){
                $this->error_text = 'The RegisterONE For WordPress plugin requires at least PHP 5.2.6.';
            }
            if( version_compare( get_bloginfo( 'version' ), '3.1', '<')){
                $this->error_text = 'The RegisterONE For WordPress plugin requires at least WordPress version 3.1.';
            }

            if($this->error_text !== ''){
                add_action('admin_notices', array($this, 'dwc_version_require'), $this->error_text);
                // add_option(RegisteroneAccountInformation::$key, RegisteroneAccountInformation::get_settings_defaults(), '', 'yes');
            }

            add_option(RegisteroneAccountInformation::$key, RegisteroneAccountInformation::get_settings_defaults(), '', 'yes');
        }

        public function dwc_plugin_deactivation()
        {
            delete_option('dwc_account_information');
            delete_option('dwc_advanced_settings');
            delete_option('dwc_form_custom');
            delete_option('dwc_form_setup');
        }
    }

    $GLOBALS['registerone_wordpress_client'] = new RegisteroneWordpressClient();
}

/*
function registerone_flush_rewrite_rules() {

    global $wp_rewrite;

    $wp_rewrite->flush_rules();

} // End flush_rewrite_rules()
add_action( 'init', 'registerone_flush_rewrite_rules' );
*/

/*
 * Dynamic form support
 * ref. https://codex.wordpress.org/Rewrite_API/add_rewrite_rule#Using_Custom_Templates_with_custom_querystring
 * Usage: [registerone_form form_key="dynamic"]
 * domain.com/form/{form_key}/
 * re-writes internal query as: /?pagename=form&form_key={form_key}
 *
 * Dynamic form_key with url slug
 * $attributes['form_key'] = $attributes['form_key'] == 'dynamic' ? $wp_query->query_vars['form_key'] : $attributes['form_key'];
 * */
function registerone_rewrite_tag() {
    add_rewrite_tag('%form_key%', '([^&]+)');
    add_rewrite_tag('%id_hash%', '([^&]+)');
}

function registerone_rewrite_rule() {
    // writes internal query as: /?pagename=form&form_key={form_key}
    add_rewrite_rule('([^/]*)/([^/]*)/?', 'index.php?pagename=form&id_hash=$matches[1]&form_key=$matches[2]', 'top');
}

add_action('init', 'registerone_rewrite_tag', 10, 0);
add_action('init', 'registerone_rewrite_rule', 10, 0);
